@@ -34,18 +34,18 @@ class DimDisplay : public PowerDevil::Action
 
 public:
     explicit DimDisplay(QObject *parent);
-    virtual ~DimDisplay() = default;
+    ~DimDisplay() override = default;
 
 protected:
-    void onProfileUnload() Q_DECL_OVERRIDE;
-    void onWakeupFromIdle() Q_DECL_OVERRIDE;
-    void onIdleTimeout(int msec) Q_DECL_OVERRIDE;
-    void onProfileLoad() Q_DECL_OVERRIDE;
-    void triggerImpl(const QVariantMap& args) Q_DECL_OVERRIDE;
-    bool isSupported() Q_DECL_OVERRIDE;
+    void onProfileUnload() override;
+    void onWakeupFromIdle() override;
+    void onIdleTimeout(int msec) override;
+    void onProfileLoad() override;
+    void triggerImpl(const QVariantMap& args) override;
+    bool isSupported() override;
 
 public:
-    bool loadAction(const KConfigGroup& config) Q_DECL_OVERRIDE;
+    bool loadAction(const KConfigGroup& config) override;
 
 private:
     void setBrightnessHelper(int screen, int keyboard, bool force = false);
